@@ -14,6 +14,7 @@ import warnings
 from datetime import datetime
 from functools import wraps
 import logging
+from enum import Enum
 
 logger = logging.getLogger(__name__)
 
@@ -35,7 +36,6 @@ try:
 except ImportError:
     pass
 
-
 _SESSION_STUFF = {
     "calcbench_user_name": os.environ.get("CALCBENCH_USERNAME"),
     "calcbench_password": os.environ.get("CALCBENCH_PASSWORD"),
@@ -55,9 +55,12 @@ def _calcbench_session():
         user_name = _SESSION_STUFF.get("calcbench_user_name")
         password = _SESSION_STUFF.get("calcbench_password")
         if not (user_name and password):
-            raise ValueError(
-                "No credentials supplied, either call set_credentials or set \
-                                CALCBENCH_USERNAME and CALCBENCH_PASSWORD environment variables."
+            import getpass
+            user_name = input(
+                'Calcbench username/email. Set the "calcbench_user_name" environment variable or call "set_credentials" to avoid this prompt::'
+            )
+            password = getpass.getpass(
+                'Calcbench password.  Set the "calcbench_password" enviroment variable to avoid this prompt::'
             )
         session = requests.Session()
         if _SESSION_STUFF.get("proxies"):
@@ -180,14 +183,24 @@ def enable_backoff(backoff_on=True, giveup=lambda e: False):
         import backoff
 
         _SESSION_STUFF["backoff_package"] = backoff
+
     _SESSION_STUFF["enable_backoff"] = backoff_on
     _SESSION_STUFF["backoff_giveup"] = giveup
 
 
 def set_proxies(proxies):
+    """
+        Set proxies used for requests.  See https://requests.readthedocs.io/en/master/user/advanced/#proxies
+
+    """
     _SESSION_STUFF["proxies"] = proxies
 
 
+class CompanyIdentifierScheme(Enum):
+    Ticker = "ticker"
+    CentralIndexKey = "CIK"
+
+
 def normalized_dataframe(
     company_identifiers=[],
     metrics=[],
@@ -204,6 +217,7 @@ def normalized_dataframe(
     period_type=None,
     trace_hyperlinks=False,
     use_fiscal_period=False,
+    company_identifier_scheme=CompanyIdentifierScheme.Ticker,
 ):
     """Standardized Data.
     
@@ -229,6 +243,7 @@ def normalized_dataframe(
       >>> calcbench.standardized_data(company_identifiers=['msft', 'goog'], metrics=['revenue', 'assets'], all_history=True, period_type='annual')
 
     """
+    company_identifier_scheme = CompanyIdentifierScheme(company_identifier_scheme)
     if all_history and not period_type:
         raise ValueError("For all history you must specify a period_type")
     data = normalized_raw(
@@ -276,7 +291,9 @@ def normalized_dataframe(
     if missing_metrics:
         warnings.warn("Did not find metrics {0}".format(missing_metrics))
     data = pd.DataFrame(data)
-    data.set_index(keys=["ticker", "metric", "period"], inplace=True)
+    data.set_index(
+        keys=[company_identifier_scheme.value, "metric", "period"], inplace=True
+    )
     try:
         data = data.unstack("metric")["value"]
     except ValueError as e:
@@ -295,7 +312,7 @@ def normalized_dataframe(
 
     for missing_metric in missing_metrics:
         data[missing_metric] = np.nan  # We want columns for every requested metric.
-    data = data.unstack("ticker")
+    data = data.unstack(company_identifier_scheme.value)
     return data
 
 
@@ -581,6 +598,7 @@ def point_in_time(
     data = pd.DataFrame(data)
 
     sort_columns = ["ticker", "metric"]
+
     if "calendar_period" in data.columns:
         data.calendar_period = data.calendar_period.astype(period_number)
         sort_columns.extend(["calendar_year", "calendar_period"])
@@ -614,7 +632,7 @@ def mapped_raw(
     include_xbrl=True,
     accession_id=None,
     include_trace=False,
-):
+) -> pd.DataFrame:
     if update_date:
         warnings.warn(
             "Request updates by accession_id rather than update date",
@@ -654,63 +672,42 @@ def mapped_raw(
     return _json_POST("mappedData", payload)
 
 
-def as_reported_raw(
+def face_statement(
     company_identifier,
     statement_type,
     period_type="annual",
-    all_periods=False,
+    all_history=False,
     descending_dates=False,
 ):
-    """
-    As-Reported Data.
+    """Face Statements.
     
-    Get statements as reported by the filing company
+    face statements as reported by the filing company
     
-    Args:
-        company_identifier: a ticker or a CIK code, eg 'msft'
-        statement_type: one of ('income', 'balance', 'cash', 'change-in-equity', 'comprehensive-income')
-        period_type: either 'annual' or 'quarterly'
-        all_periods: get all history or only the last four, True or False.
-        descending_dates: return columns in oldest -> newest order.
+    
+    :param string company_identifier: a ticker or a CIK code, eg 'msft'
+    :param string statement_type: one of ('income', 'balance', 'cash', 'change-in-equity', 'comprehensive-income')
+    :param string period_type: annual|quarterly|cummulative|combined
+    :param string all_periods: get all history or only the last four, True or False.
+    :param bool descending_dates: return columns in oldest -> newest order.
         
+    :rtype: object
+
     Returns:
-        An object with columns and line items lists.  The columns have fiscal_period, period_start, period_end and instant values.
-        The line items have label, local_name (the XBRL tag name), tree_depth (the indent amount), is_subtotal (whether or not the line item is computed from above metrics) and facts.
-        The facts are in the same order as the columns and have fact_ids (an internal Calcbench ID), unit_of_measure (USD etc), effective_value (the reported value), and format_type.
-         
-         Example:
-             {
-                "entity_name": "Microsoft Corp",
-                "name": "INCOME STATEMENTS",
-                "period_type": 2,
-                "columns": [
-                            {"fiscal_period": "Y 2008",
-                            "period_start": "2007-07-01",
-                            "period_end": "2008-06-30",
-                            "instant": false
-                        },...],
-                "line_items" : [
-                            {"label": "Revenue",
-                            "local_name": "SalesRevenueNet",
-                            "tree_depth": 3,
-                            "is_subtotal": false,
-                            "facts": [
-                                {
-                                    "fact_id": 5849672,
-                                    "unit_of_measure": "USD",
-                                    "effective_value": 60420000000,
-                                    "format_type": "currency",
-                                    "text_fact_id": 5849351
-                                },...]}
-                    ...]
-                }        
+    An object with columns and line items lists.  The columns have fiscal_period, period_start, period_end and instant values.
+    The line items have label, local_name (the XBRL tag name), tree_depth (the indent amount), is_subtotal (whether or not the line item is computed from above metrics) and facts.
+    The facts are in the same order as the columns and have fact_ids (an internal Calcbench ID), unit_of_measure (USD etc), effective_value (the reported value), and format_type.
+        
+
+    Usage::
+        >>> calcbench.face_statement('msft', 'income')
+
     """
     url = _SESSION_STUFF["api_url_base"].format("asReported")
     payload = {
         "companyIdentifier": company_identifier,
         "statementType": statement_type,
         "periodType": period_type,
-        "allPeriods": all_periods,
+        "allPeriods": all_history,
         "descendingDates": descending_dates,
     }
     response = _calcbench_session().get(
@@ -724,6 +721,9 @@ def as_reported_raw(
     return data
 
 
+as_reported_raw = face_statement
+
+
 def dimensional_raw(
     company_identifiers=None,
     metrics=[],
@@ -1036,7 +1036,11 @@ def tickers(
 
     """
     companies = _companies(
-        SIC_codes, index, company_identifiers, entire_universe, NAICS_codes=NAICS_codes
+        SIC_codes,
+        index,
+        list(company_identifiers),
+        entire_universe,
+        NAICS_codes=NAICS_codes,
     )
     tickers = [co["ticker"] for co in companies]
     return tickers
@@ -1062,7 +1066,7 @@ def companies(
     companies = _companies(
         SIC_codes,
         index,
-        company_identifiers,
+        list(company_identifiers),
         entire_universe,
         include_most_recent_filing_dates,
         NAICS_codes=NAICS_codes,
@@ -1097,11 +1101,11 @@ def _companies(
     elif NAICS_codes:
         payload["NAICSCodes"] = NAICS_codes
     elif company_identifiers:
-        payload["companyIdentifiers"] = ",".join(company_identifiers)
+        payload["companyIdentifiers"] = company_identifiers
     else:
         payload["universe"] = True
     payload["includeMostRecentFilingExtras"] = include_most_recent_filing_dates
-    return _json_GET("api/companies", payload)
+    return _json_POST("companies", payload)
 
 
 def companies_raw(
@@ -1324,14 +1328,8 @@ def raw_data_raw(
                 }
             else:
                 result["dimensions"] = []
+
     return results
 
 
 raw_xbrl_raw = raw_data_raw
-
-
-if __name__ == "__main__":
-    from datetime import date
-
-    point_in_time(all_face=True, company_identifiers=["BELFB"], all_history=True)
-
