@@ -1,13 +1,12 @@
 #!/usr/bin/env python
 # coding: utf-8
 try:
-    from azure.servicebus import SubscriptionClient
+    from azure.servicebus import ServiceBusClient
 except ImportError:
     "Will not be able to use the listener"
     pass
 
 import json
-import warnings
 import logging
 
 from .api_client import _cast_filing_fields
@@ -17,9 +16,7 @@ logger = logging.getLogger(__name__)
 TOPIC = "filings"
 
 
-def handle_filings(
-    handler, connection_string, subscription_name, filter_expression="1=1"
-):
+def handle_filings(handler, connection_string, subscription_name):
     """Listen for new filings from Calcbench
 
     Pass in a function that process each filing.
@@ -42,22 +39,22 @@ def handle_filings(
         >>>     subscription_name=subscription,
         >>> )
     """
-    sub_client = SubscriptionClient.from_connection_string(
-        conn_str=connection_string, name=subscription_name, topic=TOPIC
-    )
-
-    for message in sub_client.get_receiver():
-        try:
-            body_bytes = b"".join(message.body)
-            filing = json.loads(body_bytes)
-            filing = _cast_filing_fields(filing)
-        except Exception:
-            logger.exception(f"Exception Parsing {body_bytes}")
-            message.abandon()
-        else:
-            try:
-                handler(filing)
-            except Exception as e:
-                logger.exception(f"Exception Processing {filing}\n{e}")
-            else:
-                message.complete()
\ No newline at end of file
+    with ServiceBusClient.from_connection_string(conn_str=connection_string) as client:
+        with client.get_subscription_receiver(
+            topic_name=TOPIC, subscription_name=subscription_name
+        ) as receiver:
+            for message in receiver:
+                body_bytes = b"".join(message.body)
+                try:
+                    filing = json.loads(body_bytes)
+                    filing = _cast_filing_fields(filing)
+                except Exception:
+                    logger.exception(f"Exception Parsing {body_bytes}")
+                    message.abandon()
+                else:
+                    try:
+                        handler(filing)
+                    except Exception as e:
+                        logger.exception(f"Exception Processing {filing}\n{e}")
+                    else:
+                        message.complete()
